otcextensions.sdk.anti_ddos.v1.status
=====================================

.. automodule:: otcextensions.sdk.anti_ddos.v1.status

The Anti DDoS TaskStatus Class
------------------------------

The ``TaskStatus`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.anti_ddos.v1.status.TaskStatus
   :members:

The Anti DDoS FloatingIPStatus Class
------------------------------------

The ``FloatingIPStatus`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.anti_ddos.v1.status.FloatingIPStatus
   :members:

The Anti DDoS FloatingIPEvent Class
-----------------------------------

The ``FloatingIPEvent`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.anti_ddos.v1.status.FloatingIPEvent
   :members:

The Anti DDoS FloatingIPDayStat Class
-------------------------------------

The ``FloatingIPDayStat`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.anti_ddos.v1.status.FloatingIPDayStat
   :members:

The Anti DDoS FloatingIPWeekStatData Class
------------------------------------------

The ``FloatingIPWeekStatData`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.anti_ddos.v1.status.FloatingIPWeekStatData
   :members:

The Anti DDoS FloatingIPWeekStat Class
--------------------------------------

The ``FloatingIPWeekStat`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.anti_ddos.v1.status.FloatingIPWeekStat
   :members:
